==> jc-1.4.0.tar.gz: java/awt/font/TextMeasurer.h <==
// public final class java.awt.font.TextMeasurer

// class file dependencies
// @dep_class 2aa3f4d17bbb9c42 java_awt_font_TextMeasurer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TextMeasurer_H_
#define _JC_java_awt_font_TextMeasurer_H_

// Forward structure declarations
struct _jc_java_awt_font_FontRenderContext$object;
struct _jc_java_awt_font_TextLayout$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_text_AttributedCharacterIterator$object;

// Typedefs
typedef struct _jc_java_awt_font_TextMeasurer$sub_refs	_jc_java_awt_font_TextMeasurer$sub_refs;
typedef struct _jc_java_awt_font_TextMeasurer$sub_nonrefs	_jc_java_awt_font_TextMeasurer$sub_nonrefs;
typedef struct _jc_java_awt_font_TextMeasurer$refs	_jc_java_awt_font_TextMeasurer$refs;
typedef struct _jc_java_awt_font_TextMeasurer$nonrefs	_jc_java_awt_font_TextMeasurer$nonrefs;
typedef struct _jc_java_awt_font_TextMeasurer$object	_jc_java_awt_font_TextMeasurer$object;

typedef const struct _jc_java_awt_font_TextMeasurer$vmethods	_jc_java_awt_font_TextMeasurer$vmethods;
typedef const struct _jc_java_awt_font_TextMeasurer$vtable	_jc_java_awt_font_TextMeasurer$vtable;
typedef const struct _jc_java_awt_font_TextMeasurer$vtype	_jc_java_awt_font_TextMeasurer$vtype;

// Constructors
extern void _jc_java_awt_font_TextMeasurer$method$_init$02cc1853971ba61d(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, struct _jc_java_awt_font_FontRenderContext$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_font_TextMeasurer$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *);
extern void _jc_java_awt_font_TextMeasurer$method$deleteChar$4aaa3232ee6755d9(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint);
extern jfloat _jc_java_awt_font_TextMeasurer$method$getAdvanceBetween$33b85c6c4a66dceb(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint);
extern struct _jc_java_awt_font_TextLayout$object *_jc_java_awt_font_TextMeasurer$method$getLayout$bebaba4ad69ea837(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint);
extern jint _jc_java_awt_font_TextMeasurer$method$getLineBreakIndex$ca6096f8ad3b64a4(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jfloat);
extern void _jc_java_awt_font_TextMeasurer$method$insertChar$3a7b0ab0bbf972e8(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$deleteChar$4aaa3232ee6755d9;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getAdvanceBetween$33b85c6c4a66dceb;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getLayout$bebaba4ad69ea837;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getLineBreakIndex$ca6096f8ad3b64a4;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$insertChar$3a7b0ab0bbf972e8;

// Virtual methods structure
struct _jc_java_awt_font_TextMeasurer$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *);
	void	(*deleteChar$4aaa3232ee6755d9)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint);
	jfloat	(*getAdvanceBetween$33b85c6c4a66dceb)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint);
	struct _jc_java_awt_font_TextLayout$object	*(*getLayout$bebaba4ad69ea837)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint);
	jint	(*getLineBreakIndex$ca6096f8ad3b64a4)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jfloat);
	void	(*insertChar$3a7b0ab0bbf972e8)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint);
};

// Vtable
struct _jc_java_awt_font_TextMeasurer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TextMeasurer$vmethods	java_awt_font_TextMeasurer;
};

// Vtype
struct _jc_java_awt_font_TextMeasurer$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextMeasurer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextMeasurer$sub_refs {
	struct _jc_object	*ci;
	struct _jc_java_awt_font_FontRenderContext$object	*frc;
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextMeasurer$refs {
    _jc_java_awt_font_TextMeasurer$sub_refs	java_awt_font_TextMeasurer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextMeasurer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextMeasurer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TextMeasurer$sub_nonrefs	java_awt_font_TextMeasurer;
};

// Object instance structure
struct _jc_java_awt_font_TextMeasurer$object {
	_jc_java_awt_font_TextMeasurer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextMeasurer$vtype	*vtype;
	_jc_java_awt_font_TextMeasurer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextMeasurer$vtype _jc_java_awt_font_TextMeasurer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextMeasurer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextMeasurer$class_object;

#endif	/* _JC_java_awt_font_TextMeasurer_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/TextMeasurer.h <==
// public final class java.awt.font.TextMeasurer

// class file dependencies
// @dep_class 2aa3f4d17bbb9c42 java_awt_font_TextMeasurer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TextMeasurer_H_
#define _JC_java_awt_font_TextMeasurer_H_

// Forward structure declarations
struct _jc_java_awt_font_FontRenderContext$object;
struct _jc_java_awt_font_TextLayout$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_text_AttributedCharacterIterator$object;

// Typedefs
typedef struct _jc_java_awt_font_TextMeasurer$sub_refs	_jc_java_awt_font_TextMeasurer$sub_refs;
typedef struct _jc_java_awt_font_TextMeasurer$sub_nonrefs	_jc_java_awt_font_TextMeasurer$sub_nonrefs;
typedef struct _jc_java_awt_font_TextMeasurer$refs	_jc_java_awt_font_TextMeasurer$refs;
typedef struct _jc_java_awt_font_TextMeasurer$nonrefs	_jc_java_awt_font_TextMeasurer$nonrefs;
typedef struct _jc_java_awt_font_TextMeasurer$object	_jc_java_awt_font_TextMeasurer$object;

typedef const struct _jc_java_awt_font_TextMeasurer$vmethods	_jc_java_awt_font_TextMeasurer$vmethods;
typedef const struct _jc_java_awt_font_TextMeasurer$vtable	_jc_java_awt_font_TextMeasurer$vtable;
typedef const struct _jc_java_awt_font_TextMeasurer$vtype	_jc_java_awt_font_TextMeasurer$vtype;

// Constructors
extern void _jc_java_awt_font_TextMeasurer$method$_init$02cc1853971ba61d(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_font_TextMeasurer$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_font_TextMeasurer$method$deleteChar$4aaa3232ee6755d9(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_TextMeasurer$method$getAdvanceBetween$33b85c6c4a66dceb(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_font_TextLayout$object *_jc_java_awt_font_TextMeasurer$method$getLayout$bebaba4ad69ea837(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_java_awt_font_TextMeasurer$method$getLineBreakIndex$ca6096f8ad3b64a4(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jfloat) _JC_JCNI_ATTR;
extern void _jc_java_awt_font_TextMeasurer$method$insertChar$3a7b0ab0bbf972e8(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$deleteChar$4aaa3232ee6755d9;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getAdvanceBetween$33b85c6c4a66dceb;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getLayout$bebaba4ad69ea837;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$getLineBreakIndex$ca6096f8ad3b64a4;
extern _jc_method _jc_java_awt_font_TextMeasurer$method_info$insertChar$3a7b0ab0bbf972e8;

// Virtual methods structure
struct _jc_java_awt_font_TextMeasurer$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *) _JC_JCNI_ATTR;
	void	(*deleteChar$4aaa3232ee6755d9)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
	jfloat	(*getAdvanceBetween$33b85c6c4a66dceb)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_awt_font_TextLayout$object	*(*getLayout$bebaba4ad69ea837)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jint) _JC_JCNI_ATTR;
	jint	(*getLineBreakIndex$ca6096f8ad3b64a4)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, jint, jfloat) _JC_JCNI_ATTR;
	void	(*insertChar$3a7b0ab0bbf972e8)(_jc_env *, struct _jc_java_awt_font_TextMeasurer$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_TextMeasurer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TextMeasurer$vmethods	java_awt_font_TextMeasurer;
};

// Vtype
struct _jc_java_awt_font_TextMeasurer$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextMeasurer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextMeasurer$sub_refs {
	struct _jc_object	*ci;
	struct _jc_java_awt_font_FontRenderContext$object	*frc;
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextMeasurer$refs {
    _jc_java_awt_font_TextMeasurer$sub_refs	java_awt_font_TextMeasurer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextMeasurer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextMeasurer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TextMeasurer$sub_nonrefs	java_awt_font_TextMeasurer;
};

// Object instance structure
struct _jc_java_awt_font_TextMeasurer$object {
	_jc_java_awt_font_TextMeasurer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextMeasurer$vtype	*vtype;
	_jc_java_awt_font_TextMeasurer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextMeasurer$vtype _jc_java_awt_font_TextMeasurer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextMeasurer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextMeasurer$class_object;

#endif	/* _JC_java_awt_font_TextMeasurer_H_ */
